@@ -7,8 +7,6 @@ from pathlib import Path
 from typing import Any, BinaryIO, Dict, List, Optional, Tuple, Union
 from uuid import uuid4
 
-from google.cloud.storage import Bucket
-from google.cloud.storage.blob import Blob
 from prefect import get_run_logger, task
 from prefect.blocks.abstract import ObjectStorageBlock
 from prefect.filesystems import WritableDeploymentStorage, WritableFileSystem
@@ -21,6 +19,12 @@ from pydantic import Field, validator
 # TypeError: issubclass() arg 1 must be a class
 from prefect_gcp.credentials import GcpCredentials
 
+try:
+    from google.cloud.storage import Bucket
+    from google.cloud.storage.blob import Blob
+except ModuleNotFoundError:
+    pass
+
 
 @task
 async def cloud_storage_create_bucket(
@@ -707,7 +711,7 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
         return bucket
 
     @sync_compatible
-    async def list_blobs(self, folder: str = "") -> List[Blob]:
+    async def list_blobs(self, folder: str = "") -> List["Blob"]:
         """
         Lists all blobs in the bucket that are in a folder.
         Folders are not included in the output.
